@@ -23,7 +23,7 @@ except:
 
 from couchdbkit.resource import ResourceNotFound, ResourceConflict
 from couchdbkit.client import Server, Database
-from couchdbkit.schema import Document
+from couchdbkit.schema import *
 from couchdbkit.properties import *
 from couchdbkit.properties_proxy import *
 from couchdbkit.session import create_session
\ No newline at end of file
