@@ -528,16 +528,25 @@ class QueryMixin(object):
         results are wrapped to current document instance.
         """
         def default_wrapper(row):
-            data = row['value']
+            data = row.get('value')
+            docid = row.get('id')
+            if not data or data is None:
+                doc = row.get('doc', False)
+                if doc:
+                    return cls.wrap(doc)
+                return row
             data['_id'] = row.get('id')
             obj = cls.wrap(data)
             return obj
         
         if wrapper is None:
             wrapper = default_wrapper
-        if not callable(wrapper):
-            raise TypeError("wrapper is not a callable")
             
+        if not wrapper:
+            wrapper = None
+        elif not callable(wrapper):
+            raise TypeError("wrapper is not a callable")
+        
         db = cls.get_db()
         return db.view(view_name, wrapper=wrapper, **params)
         
@@ -555,6 +564,11 @@ class QueryMixin(object):
         """
         def default_wrapper(row):
             data = row['value']
+            if not data or data is None:
+                doc = row.get('doc', False)
+                if doc:
+                    return cls.wrap(doc)
+                return row
             data['_id'] = row.get('id')
             obj = cls.wrap(data)
             return obj
