@@ -267,7 +267,85 @@ class DocumentTestCase(unittest.TestCase):
         self.assert_(hasattr(doc3, "field1"))
         self.server.delete_db('simplecouchdb_test')
     
+    def testViewNoneValue(self):
+        class TestDoc(Document):
+            field1 = StringProperty()
+            field2 = StringProperty()
 
+        design_doc = {
+            '_id': '_design/test',
+            'language': 'javascript',
+            'views': {
+                'all': {
+                    "map": """function(doc) { if (doc.doc_type == "TestDoc") { emit(doc._id, null);
+}}"""
+                }
+            }
+        }
+        doc = TestDoc(field1="a", field2="b")
+        doc1 = TestDoc(field1="c", field2="d")
+
+        db = self.server.create_db('simplecouchdb_test')
+        TestDoc._db = db
+        
+        doc.save()
+        doc1.save()
+        db.save_doc(design_doc)
+        results = TestDoc.view('test/all')
+        self.assert_(len(results) == 2)
+        self.assert_(isinstance(results.first(), dict) == True)
+        results2 = TestDoc.view('test/all', include_docs=True)
+        self.assert_(len(results2) == 2)
+        self.assert_(isinstance(results2.first(), TestDoc) == True)       
+        self.server.delete_db('simplecouchdb_test')
+        
+        
+    def testOne(self):
+        class TestDoc(Document):
+            field1 = StringProperty()
+            field2 = StringProperty()
+
+        design_doc = {
+            '_id': '_design/test',
+            'language': 'javascript',
+            'views': {
+                'all': {
+                    "map": """function(doc) { if (doc.doc_type == "TestDoc") { emit(doc._id, doc);
+}}"""
+                }
+            }
+        }
+        doc = TestDoc(field1="a", field2="b")
+        doc1 = TestDoc(field1="c", field2="d")
+
+        db = self.server.create_db('simplecouchdb_test')
+        TestDoc._db = db
+
+       
+        db.save_doc(design_doc)
+        results = TestDoc.view('test/all')
+        self.assert_(len(results) == 0)
+        self.assertRaises(NoResultFound, results.one, except_all=True)
+        rst = results.one()
+        self.assert_(rst is None)
+        
+        
+        results = TestDoc.view('test/all')
+        doc.save()
+        self.assert_(len(results) == 1)
+        
+        one = results.one()
+        self.assert_(isinstance(one, TestDoc) == True)
+        
+        doc1.save()
+        results = TestDoc.view('test/all')
+        self.assert_(len(results) == 2)
+        
+        self.assertRaises(MultipleResultsFound, results.one)
+        
+        
+       
+        self.server.delete_db('simplecouchdb_test')
 
     def testTempView(self):
         class TestDoc(Document):
@@ -744,6 +822,26 @@ class PropertyTestCase(unittest.TestCase):
         self.assert_(b._doc['l'] == ['2009-04-13T22:56:10Z'])
         self.server.delete_db('simplecouchdb_test')
         
+    def testDictProperty(self):
+        from datetime import datetime
+        class A(Document):
+            d = DictProperty()
+            
+        a = A()
+        self.assert_(a._doc == {'d': {}, 'doc_type': 'A'})
+        a.d['s'] = 'test'
+        self.assert_(a._doc == {'d': {'s': 'test'}, 'doc_type': 'A'})
+        a.d['created'] = datetime(2009, 4, 16, 16, 5, 41)
+        self.assert_(a._doc == {'d': {'created': '2009-04-16T16:05:41Z', 's': 'test'}, 'doc_type': 'A'})
+        self.assert_(isinstance(a.d['created'], datetime) == True)
+        a.d.update({'s2': 'test'})
+        self.assert_(a.d['s2'] == 'test')
+        a.d.update({'d2': datetime(2009, 4, 16, 16, 5, 41)})
+        self.assert_(a._doc['d']['d2'] == '2009-04-16T16:05:41Z')
+        self.assert_(a.d['d2'] == datetime(2009, 4, 16, 16, 5, 41))
+        
+        
+        
 
 if __name__ == '__main__':
     unittest.main()
